==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/WriteTreatmentResource.scala <==
package zio.aws.pinpoint.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.{__string, __integer}
import scala.jdk.CollectionConverters.*
final case class WriteTreatmentResource(
    customDeliveryConfiguration: Option[
      zio.aws.pinpoint.model.CustomDeliveryConfiguration
    ] = None,
    messageConfiguration: Option[zio.aws.pinpoint.model.MessageConfiguration] =
      None,
    schedule: Option[zio.aws.pinpoint.model.Schedule] = None,
    sizePercent: __integer,
    templateConfiguration: Option[
      zio.aws.pinpoint.model.TemplateConfiguration
    ] = None,
    treatmentDescription: Option[__string] = None,
    treatmentName: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource = {
    import WriteTreatmentResource.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
      .builder()
      .optionallyWith(
        customDeliveryConfiguration.map(value => value.buildAwsValue())
      )(_.customDeliveryConfiguration)
      .optionallyWith(messageConfiguration.map(value => value.buildAwsValue()))(
        _.messageConfiguration
      )
      .optionallyWith(schedule.map(value => value.buildAwsValue()))(_.schedule)
      .sizePercent(__integer.unwrap(sizePercent): Integer)
      .optionallyWith(
        templateConfiguration.map(value => value.buildAwsValue())
      )(_.templateConfiguration)
      .optionallyWith(
        treatmentDescription.map(value =>
          __string.unwrap(value): java.lang.String
        )
      )(_.treatmentDescription)
      .optionallyWith(
        treatmentName.map(value => __string.unwrap(value): java.lang.String)
      )(_.treatmentName)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.WriteTreatmentResource.ReadOnly =
    zio.aws.pinpoint.model.WriteTreatmentResource.wrap(buildAwsValue())
}
object WriteTreatmentResource {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.WriteTreatmentResource =
      zio.aws.pinpoint.model.WriteTreatmentResource(
        customDeliveryConfiguration.map(value => value.asEditable),
        messageConfiguration.map(value => value.asEditable),
        schedule.map(value => value.asEditable),
        sizePercent,
        templateConfiguration.map(value => value.asEditable),
        treatmentDescription.map(value => value),
        treatmentName.map(value => value)
      )
    def customDeliveryConfiguration
        : Option[zio.aws.pinpoint.model.CustomDeliveryConfiguration.ReadOnly]
    def messageConfiguration
        : Option[zio.aws.pinpoint.model.MessageConfiguration.ReadOnly]
    def schedule: Option[zio.aws.pinpoint.model.Schedule.ReadOnly]
    def sizePercent: __integer
    def templateConfiguration
        : Option[zio.aws.pinpoint.model.TemplateConfiguration.ReadOnly]
    def treatmentDescription: Option[__string]
    def treatmentName: Option[__string]
    def getCustomDeliveryConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.pinpoint.model.CustomDeliveryConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "customDeliveryConfiguration",
      customDeliveryConfiguration
    )
    def getMessageConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.pinpoint.model.MessageConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("messageConfiguration", messageConfiguration)
    def getSchedule
        : ZIO[Any, AwsError, zio.aws.pinpoint.model.Schedule.ReadOnly] =
      AwsError.unwrapOptionField("schedule", schedule)
    def getSizePercent: ZIO[Any, Nothing, __integer] = ZIO.succeed(sizePercent)
    def getTemplateConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.pinpoint.model.TemplateConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("templateConfiguration", templateConfiguration)
    def getTreatmentDescription: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("treatmentDescription", treatmentDescription)
    def getTreatmentName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("treatmentName", treatmentName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
  ) extends zio.aws.pinpoint.model.WriteTreatmentResource.ReadOnly {
    override val customDeliveryConfiguration
        : Option[zio.aws.pinpoint.model.CustomDeliveryConfiguration.ReadOnly] =
      scala
        .Option(impl.customDeliveryConfiguration())
        .map(value =>
          zio.aws.pinpoint.model.CustomDeliveryConfiguration.wrap(value)
        )
    override val messageConfiguration
        : Option[zio.aws.pinpoint.model.MessageConfiguration.ReadOnly] = scala
      .Option(impl.messageConfiguration())
      .map(value => zio.aws.pinpoint.model.MessageConfiguration.wrap(value))
    override val schedule: Option[zio.aws.pinpoint.model.Schedule.ReadOnly] =
      scala
        .Option(impl.schedule())
        .map(value => zio.aws.pinpoint.model.Schedule.wrap(value))
    override val sizePercent: __integer =
      zio.aws.pinpoint.model.primitives.__integer(impl.sizePercent())
    override val templateConfiguration
        : Option[zio.aws.pinpoint.model.TemplateConfiguration.ReadOnly] = scala
      .Option(impl.templateConfiguration())
      .map(value => zio.aws.pinpoint.model.TemplateConfiguration.wrap(value))
    override val treatmentDescription: Option[__string] = scala
      .Option(impl.treatmentDescription())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
    override val treatmentName: Option[__string] = scala
      .Option(impl.treatmentName())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
  ): zio.aws.pinpoint.model.WriteTreatmentResource.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/WriteTreatmentResource.scala <==
package zio.aws.pinpoint.model
import zio.prelude.data.Optional
import zio.aws.pinpoint.model.primitives.{__string, __integer}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class WriteTreatmentResource(
    customDeliveryConfiguration: Optional[
      zio.aws.pinpoint.model.CustomDeliveryConfiguration
    ] = Optional.Absent,
    messageConfiguration: Optional[
      zio.aws.pinpoint.model.MessageConfiguration
    ] = Optional.Absent,
    schedule: Optional[zio.aws.pinpoint.model.Schedule] = Optional.Absent,
    sizePercent: __integer,
    templateConfiguration: Optional[
      zio.aws.pinpoint.model.TemplateConfiguration
    ] = Optional.Absent,
    treatmentDescription: Optional[__string] = Optional.Absent,
    treatmentName: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource = {
    import WriteTreatmentResource.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
      .builder()
      .optionallyWith(
        customDeliveryConfiguration.map(value => value.buildAwsValue())
      )(_.customDeliveryConfiguration)
      .optionallyWith(messageConfiguration.map(value => value.buildAwsValue()))(
        _.messageConfiguration
      )
      .optionallyWith(schedule.map(value => value.buildAwsValue()))(_.schedule)
      .sizePercent(sizePercent: Integer)
      .optionallyWith(
        templateConfiguration.map(value => value.buildAwsValue())
      )(_.templateConfiguration)
      .optionallyWith(
        treatmentDescription.map(value => value: java.lang.String)
      )(_.treatmentDescription)
      .optionallyWith(treatmentName.map(value => value: java.lang.String))(
        _.treatmentName
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.WriteTreatmentResource.ReadOnly =
    zio.aws.pinpoint.model.WriteTreatmentResource.wrap(buildAwsValue())
}
object WriteTreatmentResource {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.WriteTreatmentResource =
      zio.aws.pinpoint.model.WriteTreatmentResource(
        customDeliveryConfiguration.map(value => value.asEditable),
        messageConfiguration.map(value => value.asEditable),
        schedule.map(value => value.asEditable),
        sizePercent,
        templateConfiguration.map(value => value.asEditable),
        treatmentDescription.map(value => value),
        treatmentName.map(value => value)
      )
    def customDeliveryConfiguration
        : Optional[zio.aws.pinpoint.model.CustomDeliveryConfiguration.ReadOnly]
    def messageConfiguration
        : Optional[zio.aws.pinpoint.model.MessageConfiguration.ReadOnly]
    def schedule: Optional[zio.aws.pinpoint.model.Schedule.ReadOnly]
    def sizePercent: __integer
    def templateConfiguration
        : Optional[zio.aws.pinpoint.model.TemplateConfiguration.ReadOnly]
    def treatmentDescription: Optional[__string]
    def treatmentName: Optional[__string]
    def getCustomDeliveryConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.pinpoint.model.CustomDeliveryConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "customDeliveryConfiguration",
      customDeliveryConfiguration
    )
    def getMessageConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.pinpoint.model.MessageConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("messageConfiguration", messageConfiguration)
    def getSchedule
        : ZIO[Any, AwsError, zio.aws.pinpoint.model.Schedule.ReadOnly] =
      AwsError.unwrapOptionField("schedule", schedule)
    def getSizePercent: ZIO[Any, Nothing, __integer] = ZIO.succeed(sizePercent)
    def getTemplateConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.pinpoint.model.TemplateConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("templateConfiguration", templateConfiguration)
    def getTreatmentDescription: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("treatmentDescription", treatmentDescription)
    def getTreatmentName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("treatmentName", treatmentName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
  ) extends zio.aws.pinpoint.model.WriteTreatmentResource.ReadOnly {
    override val customDeliveryConfiguration: Optional[
      zio.aws.pinpoint.model.CustomDeliveryConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.customDeliveryConfiguration())
      .map(value =>
        zio.aws.pinpoint.model.CustomDeliveryConfiguration.wrap(value)
      )
    override val messageConfiguration
        : Optional[zio.aws.pinpoint.model.MessageConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.messageConfiguration())
        .map(value => zio.aws.pinpoint.model.MessageConfiguration.wrap(value))
    override val schedule: Optional[zio.aws.pinpoint.model.Schedule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.schedule())
        .map(value => zio.aws.pinpoint.model.Schedule.wrap(value))
    override val sizePercent: __integer = impl.sizePercent(): __integer
    override val templateConfiguration
        : Optional[zio.aws.pinpoint.model.TemplateConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.templateConfiguration())
        .map(value => zio.aws.pinpoint.model.TemplateConfiguration.wrap(value))
    override val treatmentDescription: Optional[__string] =
      zio.aws.core.internal
        .optionalFromNullable(impl.treatmentDescription())
        .map(value => value: __string)
    override val treatmentName: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.treatmentName())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.WriteTreatmentResource
  ): zio.aws.pinpoint.model.WriteTreatmentResource.ReadOnly = new Wrapper(impl)
}
